@@ -163,7 +163,7 @@ int ehbypass;
 pointer charmacro[256];
 pointer sharpmacro[256];
 
-extern pointer defvector();
+extern pointer defvector(context *, char *, pointer, int, int);
 static pointer reploop(context *, char *);
 
 pointer ALLOWOTHERKEYS,K_ALLOWOTHERKEYS;
@@ -269,7 +269,7 @@ char *errmsg[100]={
 	"E_END",
 	};
 
-static pointer brkloop();
+static pointer brkloop(context*,char*);
 
 void unwind(ctx,p)
 register context *ctx;
@@ -903,7 +903,7 @@ static void initfeatures()
 #if Linux
   p=cons(ctx,intern(ctx,"LINUX",5,keywordpkg),p);
 #endif
-#if Linux_ppc
+#if defined(Linux_ppc) || defined(__PPC__)
   p=cons(ctx,intern(ctx,"PPC",3,keywordpkg),p);
 #endif
 #if USE_MULTI_LIB
@@ -956,6 +956,9 @@ static void initfeatures()
 #endif
 #if riscv64
   p=cons(ctx,intern(ctx,"RISCV64",7,keywordpkg),p);
+#endif
+#if loongarch64
+  p=cons(ctx,intern(ctx,"LOONGARCH64",11,keywordpkg),p);
 #endif
   {
     char tmp[32];
@@ -1145,7 +1148,7 @@ register context *ctx;
   int i,j;
   char *eusdir, *eusrt;
   char fname[1024];
-  extern pointer SRCLOAD();
+  extern pointer SRCLOAD(context*,int,pointer*);
 
   /* reset stack pointer and frame pointers*/
   j=(int)eussetjmp(topjbuf);  
@@ -1261,20 +1264,21 @@ register context *ctx;
   Spevalof(PACKAGE)=userpkg; 
 
   defvar(ctx,"*PROGRAM-NAME*",makestring(progname,strlen(progname)),lisppkg);
+  defvar(ctx,"*DEB-HOST-MULTIARCH*",makestring("@@DEB_HOST_MULTIARCH@@",strlen("@@DEB_HOST_MULTIARCH@@")),lisppkg);
 
   /* exec_module_initializers(); */
   ctx->vsp=ctx->stack;
   configure_eus(ctx); 
 
-  signal(SIGCHLD, (void (*)())eusint);
-  signal(SIGFPE,  (void (*)())eusint);
-  signal(SIGPIPE, (void (*)())eusint);
+  signal(SIGCHLD, (void (*)(int))eusint);
+  signal(SIGFPE,  (void (*)(int))eusint);
+  signal(SIGPIPE, (void (*)(int))eusint);
 #ifdef RGC
-//  signal(SIGSEGV, (void (*)())eusint); /* for debugging. R.Hanai */
+//  signal(SIGSEGV, (void (*)(int))eusint); /* for debugging. R.Hanai */
 #else
-  signal(SIGSEGV, (void (*)())eusint);
+  signal(SIGSEGV, (void (*)(int))eusint);
 #endif
-  signal(SIGBUS,  (void (*)())eusint);
+  signal(SIGBUS,  (void (*)(int))eusint);
 
   toplevel(ctx,mainargc,mainargv);
 
@@ -1299,7 +1303,7 @@ char *argv[];
   unsigned char *m;
 
 #ifdef Darwin
-  _end = sbrk(0);
+  _end = (int)(intptr_t)sbrk(0);
 #endif
 
   mypid=getpid();
