@@ -207,7 +207,7 @@ extern pointer SUBCLASSP(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern pointer DERIVEDP(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern pointer ENTERCLASS(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern void addmethod(context */*ctx*/, pointer /*meth*/, pointer /*class*/, pointer /*doc*/);
-extern void addcmethod(context */*ctx*/, pointer /*mod*/, pointer (*/*cfunc*/)(), pointer /*sel*/, pointer /*class*/, pointer /*doc*/);
+extern void addcmethod(context */*ctx*/, pointer /*mod*/, pointer (*/*cfunc*/)(context*,int,pointer*), pointer /*sel*/, pointer /*class*/, pointer /*doc*/);
 extern pointer DEFMETHOD(context */*ctx*/, pointer /*arg*/);
 extern pointer INSTANTIATE(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern pointer findmethod(context */*ctx*/, pointer /*sel*/, pointer /*search*/, pointer */*curclass*/);
@@ -295,7 +295,7 @@ extern pointer NBUTLAST(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern void lists(context */*ctx*/, pointer /*mod*/);
 /* loadelf.c */
 extern pointer SRCLOAD(context */*ctx*/, int /*n*/, pointer /*argv*/*);
-extern void add_module_initializer(char */*name*/, pointer (*/*entry*/)());
+extern void add_module_initializer(char */*name*/, pointer (*/*entry*/)(context*,int,pointer*));
 extern void exec_module_initializers(context */*ctx*/);
 extern pointer list_module_initializers(context */*ctx*/, pointer /*initnames*/);
 extern pointer list_module_initializers2(context */*ctx*/, int /*n*/, pointer */*argv*/);
@@ -303,7 +303,7 @@ extern pointer build_quote_vector(context */*ctx*/, int /*size*/, char */*string
 extern pointer eval_c_strings(context */*ctx*/, int /*size*/, const char */*strings*/*);
 extern pointer FIND_ENTRY(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern pointer FIND_ENTRY2(context */*ctx*/, int /*n*/, pointer /*argv*/*);
-extern pointer SYSMOD(void);
+extern pointer SYSMOD(context */*ctx*/, int /*n*/, pointer /*argv*/*);
 extern pointer UNBINLOAD(context */*ctx*/, int /*n*/, pointer */*argv*/);
 extern pointer BINLOAD(context */*ctx*/, int /*n*/, pointer */*argv*/);
 extern pointer SAVE(context */*ctx*/, int /*n*/, pointer /*argv*/*);
@@ -326,7 +326,7 @@ extern pointer makepkg(context */*ctx*/, pointer /*namestr*/, pointer /*nicks*/,
 extern pointer mkstream(context */*ctx*/, pointer /*dir*/, pointer /*string*/);
 extern pointer mkfilestream(context */*ctx*/, pointer /*dir*/, pointer /*string*/, int /*fno*/, pointer /*fname*/);
 extern pointer mkiostream(context */*ctx*/, pointer /*in*/, pointer /*out*/);
-extern pointer makecode(pointer /*mod*/, pointer (*/*f*/)(), pointer /*ftype*/);
+  extern pointer makecode(pointer /*mod*/, pointer (*/*f*/)(context*,int,pointer*), pointer /*ftype*/);
 extern void bumpcix(int /*m*/, int /*n*/);
 extern void recixobj(int /*newcix*/);
 extern void resetcix(pointer /*class*/, cixpair */*p*/);
@@ -338,24 +338,24 @@ extern pointer makefvector(int /*s*/);
 extern pointer defvector(context */*ctx*/, char */*name*/, pointer /*super*/, int /*elm*/, int /*size*/);
 extern pointer makematrix(context */*ctx*/, int /*row*/, int /*column*/);
 extern pointer makemodule(context */*ctx*/, int /*size*/);
-extern pointer makeclosure(pointer /*code*/, pointer /*quote*/, pointer (*/*f*/)(), pointer /*e0*/, pointer */*e1*/, pointer */*e2*/);
+extern pointer makeclosure(pointer /*code*/, pointer /*quote*/, pointer (*/*f*/)(context*,int,pointer*,pointer), pointer /*e0*/, pointer */*e1*/, pointer */*e2*/);
 extern pointer makereadtable(context */*ctx*/);
 extern pointer makelabref(pointer /*n*/, pointer /*v*/, pointer /*nxt*/);
 extern pointer makeratio(int /*num*/, int /*denom*/);
 extern pointer makebig(int /*n*/);
 extern pointer makebig1(long /*x*/);
 extern pointer makebig2(long /*hi*/, long /*lo*/);
-extern pointer defun(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)(), char * /*doc*/);
-extern pointer defunpkg(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)(), pointer /*pkg*/);
-extern pointer defmacro(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)());
+extern pointer defun(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)(context*,int,pointer*), char * /*doc*/);
+extern pointer defunpkg(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)(context*,int,pointer*), pointer /*pkg*/);
+extern pointer defmacro(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)(context*,int,pointer*));
 extern int special_index(void);
-extern pointer defspecial(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)());
+extern pointer defspecial(context */*ctx*/, char */*name*/, pointer /*mod*/, pointer (*/*f*/)(context*,pointer));
 extern pointer defconst(context */*ctx*/, char */*name*/, pointer /*val*/, pointer /*pkg*/);
 extern pointer defvar(context */*ctx*/, char */*name*/, pointer /*val*/, pointer /*pkg*/);
 extern pointer deflocal(context */*ctx*/, char */*name*/, pointer /*val*/, pointer /*pkg*/);
 extern pointer defkeyword(context */*ctx*/, char */*name*/);
-extern pointer compfun(context */*ctx*/, pointer /*sym*/, pointer /*mod*/, pointer (*/*entry*/)(), pointer /*doc*/);
-extern pointer compmacro(context */*ctx*/, pointer /*sym*/, pointer /*mod*/, pointer (*/*entry*/)(), pointer /*doc*/);
+extern pointer compfun(context */*ctx*/, pointer /*sym*/, pointer /*mod*/, pointer (*/*entry*/)(context*,int,pointer*), pointer /*doc*/);
+extern pointer compmacro(context */*ctx*/, pointer /*sym*/, pointer /*mod*/, pointer (*/*entry*/)(context*,int,pointer*), pointer /*doc*/);
 extern struct blockframe *makeblock(context */*ctx*/, pointer /*kind*/, pointer /*name*/, jmp_buf */*jbuf*/, struct blockframe */*link*/);
 extern struct fletframe *makeflet(context */*ctx*/, pointer /*nm*/, pointer /*def*/, struct fletframe */*scp*/, struct fletframe */*link*/);
 extern void mkcatchframe(context */*ctx*/, pointer /*lab*/, jmp_buf */*jbuf*/);extern void allocate_stack(context */*ctx*/, int /*n*/);
